@@ -37,16 +37,15 @@
 if( !isset($gCms) ) return;
 
 $outp = cgsi_utils::process_image($params);
-$silent = 0;
+$silent = $this->GetPreference('silent',0);
 if( isset($params['silent']) ) $silent = (int)$params['silent'];
 
-if( isset($outp['error']) && $outp['error'] != '' && !$silent )
-  {
-    $smarty->trigger_error($outp['error']);
-    return;
-  }
+if( isset($outp['error']) && $outp['error'] != '' && !$silent ) {
+  trigger_error($outp['error']);
+  return;
+}
 
-echo $outp['output'];
+if( isset($outp['output']) ) echo $outp['output'];
 
 #
 # EOF
