@@ -361,14 +361,18 @@ class cgsi_utils
     if( !$outp['error'] && !$srcfile && startswith($opp['src'],'/') ) {
       $tmp = cms_join_path($config['root_path'],$opp['src']);
       $havesrcfile = TRUE;
-      if( file_exists($tmp) ) {
+      $rp1 = realpath($config['root_path']);
+      $rp2 = realpath($tmp);
+      if( startswith($rp2,$rp1) && file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
     if( !$outp['error'] && !$srcfile ) {
       $tmp = cms_join_path($config['uploads_path'],$opp['src']);
-      if( file_exists($tmp) ) {
-	$havesrcfile = TRUE;
+      $havesrcfile = TRUE;
+      $rp1 = realpath($config['root_path']);
+      $rp2 = realpath($tmp);
+      if( startswith($rp2,$rp1) && file_exists($tmp) ) {
 	$srcfile = $tmp;
       }
     }
@@ -413,7 +417,7 @@ class cgsi_utils
 	$srcimgsize = array('width'=>$tmp[0],'height'=>$tmp[1]);
       }
     }
-    
+
     // are we automagically rotating.
     if( !$outp['error'] && $srcfile && !$opp['norotate'] && function_exists('exif_read_data') ) {
       // if there is already a rotate filter in the list, we won't override that.
